@@ -86,7 +86,7 @@
 #define KWAYLANDCLIENT_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED
-#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
+#  define KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
 #endif
 #ifdef KWAYLANDCLIENT_NO_DEPRECATED_WARNINGS
 #  define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE KWAYLANDCLIENT_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54800
+#    define KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE 0x54c00
 #  endif
 #endif
 
@@ -133,6 +133,12 @@
 #else
 #  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_53(text)
 #endif
+
+#if KWAYLANDCLIENT_DEPRECATED_WARNINGS_SINCE >= 0x54900
+#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text) KWAYLANDCLIENT_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KWAYLANDCLIENT_DEPRECATED_VERSION_5_73(text)
+#endif
 #define KWAYLANDCLIENT_DEPRECATED_VERSION_5(minor, text)      KWAYLANDCLIENT_DEPRECATED_VERSION_5_##minor(text)
 #define KWAYLANDCLIENT_DEPRECATED_VERSION(major, minor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KWAYLANDCLIENT_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KWAYLANDCLIENT_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
